/* main.h - Main header file for redir. */
/* $Id: main.h,v 2.2 1999/01/07 05:39:10 caleishm Exp caleishm $  */
/* Chris Leishman, Trevor Cohn.  Ormond College student IT department, 1998.*/

#ifndef MAIN_H
#define MAIN_H

#define TRUE 	1
#define FALSE	0
#define EOS     (char) NULL
#define EOLN    '\n'

#ifndef NOUSE_REGEX
#include <regex.h>
#endif


enum Type {CONTAINS, HOSTCONTAINS, PATHCONTAINS, SOURCECONTAINS,
           EXEMPT, HOSTEXEMPT, PATHEXEMPT, SOURCEEXEMPT};

typedef struct sstr_list {
	char *data;
#ifndef NOUSE_REGEX
	regex_t *regc;
#elif !defined NOSAVESKIP
	int *skip;
#endif
	struct sstr_list *next;
} str_list;

typedef struct _redir_list {
	int type;
	char *data;
	struct _redir_list *next;
} redir_list;

typedef struct iitem {
	int type;
	int random;
	int numredir;
	str_list *keys;
	redir_list *redirect;
	char *logfile;
	struct iitem *subs;
	struct iitem *next;
} item;

#endif
